Per-file mtime-based caching for parsed rows.
Structs
- Table
Cache - Per-table cache that tracks file mtimes to avoid re-parsing unchanged files.
Functions
- file_
mtime - Get the mtime of a file, returning None if it can’t be read.
Per-file mtime-based caching for parsed rows.