pub struct FkWatcher { /* private fields */ }Expand description
Watches a database directory for file changes and re-validates foreign keys.
Implementations
Sourceimpl FkWatcher
impl FkWatcher
Sourcepub fn start(db_path: PathBuf) -> Result<Self, MdqlError>
pub fn start(db_path: PathBuf) -> Result<Self, MdqlError>
Start watching a database directory. On any .md file change, re-runs FK validation and sends results on an internal channel.
Sourcepub fn poll(&self) -> Option<Vec<ValidationError>>
pub fn poll(&self) -> Option<Vec<ValidationError>>
Non-blocking: drain any pending FK validation results. Returns the most recent set of FK errors, or None if no changes detected.