Module cache

Module cache 

Per-file mtime-based caching for parsed rows.

Structs

TableCache
Per-table cache that tracks file mtimes to avoid re-parsing unchanged files.

Functions

file_mtime
Get the mtime of a file, returning None if it can’t be read.